@@ -1,5 +1,6 @@
 from decimal import Decimal, InvalidOperation
 from datetime import datetime, date, time
+import re
 
 from pony.utils import is_utf8, simple_decorator, throw, localbase
 from pony.converting import str2date, str2datetime
@@ -56,11 +57,22 @@ def wrap_dbapi_exceptions(func, provider, *args, **kwargs):
     except dbapi_module.Error, e: raise Error(e)
     except dbapi_module.Warning, e: raise Warning(e)
 
+version_re = re.compile('[0-9\.]+')
+
+def get_version_tuple(s):
+    m = version_re.match(s)
+    if m is not None:
+        return tuple(map(int, m.group(0).split('.')))
+    return None
+
 class DBAPIProvider(object):
     paramstyle = 'qmark'
     quote_char = '"'
     max_params_count = 200
 
+    table_if_not_exists_syntax = True
+    max_time_precision = default_time_precision = 6
+
     dbapi_module = None
     dbschema_cls = None
     translator_cls = None
@@ -75,7 +87,7 @@ class DBAPIProvider(object):
         provider.release(connection)
 
     def inspect_connection(provider, connection):
-        provider.table_if_not_exists_syntax = True
+        pass
 
     def get_default_entity_table_name(provider, entity):
         return entity.__name__
@@ -362,8 +374,8 @@ class DecimalConverter(Converter):
     def init(converter, kwargs):
         attr = converter.attr
         args = attr.args
-        if len(args) > 2: throw(TypeError, 'Too many positional parameters for Decimal (expected: precision and scale)')
-
+        if len(args) > 2: throw(TypeError, 'Too many positional parameters for Decimal '
+                                           '(expected: precision and scale), got: %s' % args)
         if args: precision = args[0]
         else: precision = kwargs.pop('precision', 12)
         if not isinstance(precision, (int, long)):
@@ -398,6 +410,10 @@ class DecimalConverter(Converter):
         converter.min_val = min_val
         converter.max_val = max_val
     def validate(converter, val):
+        if isinstance(val, float):
+            s = str(val)
+            if float(s) != val: s = repr(val)
+            val = Decimal(s)
         try: val = Decimal(val)
         except InvalidOperation, exc:
             throw(TypeError, 'Invalid value for attribute %s: %r' % (converter.attr, val))
@@ -432,18 +448,52 @@ class DateConverter(Converter):
         throw(TypeError, "Attribute %r: expected type is 'date'. Got: %r" % (converter.attr, val))
     def sql2py(converter, val):
         if not isinstance(val, date): throw(ValueError,
-            'Value of unexpected type received from database: instead of date got %s', type(val))
+            'Value of unexpected type received from database: instead of date got %s' % type(val))
         return val
     def sql_type(converter):
         return 'DATE'
 
 class DatetimeConverter(Converter):
+    sql_type_name = 'DATETIME'
+    def __init__(converter, py_type, attr=None):
+        converter.precision = None  # for the case when attr is None
+        Converter.__init__(converter, py_type, attr)
+    def init(converter, kwargs):
+        attr = converter.attr
+        args = attr.args        
+        if len(args) > 1: throw(TypeError, 'Too many positional parameters for datetime attribute %s. '
+                                           'Expected: precision, got: %r' % (attr, args))
+        provider = attr.entity._database_.provider
+        if args:
+            precision = args[0]
+            if 'precision' in kwargs: throw(TypeError,
+                'Precision for datetime attribute %s has both positional and keyword value' % attr)
+        else: precision = kwargs.pop('precision', provider.default_time_precision)
+        if not isinstance(precision, int) or not 0 <= precision <= 6: throw(ValueError,
+            'Precision value of datetime attribute %s must be between 0 and 6. Got: %r' % (attr, precision))
+        if precision > provider.max_time_precision: throw(ValueError,
+            'Precision value (%d) of attribute %s exceeds max datetime precision (%d) of %s %s'
+            % (precision, attr, provider.max_time_precision, provider.dialect, provider.server_version))
+        converter.precision = precision
     def validate(converter, val):
-        if isinstance(val, datetime): return val
-        if isinstance(val, basestring): return str2datetime(val)
-        throw(TypeError, "Attribute %r: expected type is 'datetime'. Got: %r" % (converter.attr, val))
+        if isinstance(val, datetime): pass
+        elif isinstance(val, basestring): val = str2datetime(val)
+        else: throw(TypeError, "Attribute %r: expected type is 'datetime'. Got: %r" % (converter.attr, val))
+        p = converter.precision
+        if not p: val = val.replace(microsecond=0)
+        elif p == 6: pass
+        else:
+            rounding = 10 ** (6-p)
+            microsecond = (val.microsecond // rounding) * rounding
+            val = val.replace(microsecond=microsecond)
+        return val
     def sql2py(converter, val):
-        if not isinstance(val, datetime): raise ValueError
+        if not isinstance(val, datetime): throw(ValueError,
+            'Value of unexpected type received from database: instead of datetime got %s' % type(val))
         return val
     def sql_type(converter):
-        return 'DATETIME'
+        attr = converter.attr
+        precision = converter.precision
+        if not attr or precision == attr.entity._database_.provider.default_time_precision:
+            return converter.sql_type_name
+        return converter.sql_type_name + '(%d)' % precision
