@@ -9,7 +9,7 @@ import cx_Oracle
 
 from pony.orm import core, dbschema, sqlbuilding, dbapiprovider, sqltranslation
 from pony.orm.core import log_orm, log_sql, DatabaseError
-from pony.orm.dbapiprovider import DBAPIProvider, wrap_dbapi_exceptions
+from pony.orm.dbapiprovider import DBAPIProvider, wrap_dbapi_exceptions, get_version_tuple
 from pony.utils import is_utf8, throw
 
 trigger_template = """
@@ -56,6 +56,7 @@ class OraColumn(dbschema.Column):
     auto_template = None
 
 class OraSchema(dbschema.DBSchema):
+    dialect = 'Oracle'
     table_class = OraTable
     column_class = OraColumn
 
@@ -64,9 +65,16 @@ class OraNoneMonad(sqltranslation.NoneMonad):
         assert value in (None, '')
         sqltranslation.ConstMonad.__init__(monad, translator, None)
 
+class OraConstMonad(sqltranslation.ConstMonad):
+    @staticmethod
+    def new(translator, value):
+        if value == '': value = None
+        return sqltranslation.ConstMonad.new(translator, value)    
+
 class OraTranslator(sqltranslation.SQLTranslator):
     dialect = 'Oracle'
     NoneMonad = OraNoneMonad
+    ConstMonad = OraConstMonad
 
     @classmethod
     def get_normalized_type_of(translator, value):
@@ -179,19 +187,26 @@ class OraDateConverter(dbapiprovider.DateConverter):
         return val
 
 class OraDatetimeConverter(dbapiprovider.DatetimeConverter):
-    def sql_type(converter):
-        return 'TIMESTAMP(6)'
+    sql_type_name = 'TIMESTAMP'
 
 class OraProvider(DBAPIProvider):
+    dialect = 'Oracle'
     paramstyle = 'named'
 
+    table_if_not_exists_syntax = False
+
     dbapi_module = cx_Oracle
     dbschema_cls = OraSchema
     translator_cls = OraTranslator
     sqlbuilder_cls = OraBuilder
 
     def inspect_connection(provider, connection):
-        provider.table_if_not_exists_syntax = False
+        sql = "select version from product_component_version where product like 'Oracle Database %'"
+        cursor = connection.cursor()
+        cursor.execute(sql)
+        row = cursor.fetchone()
+        assert row is not None
+        provider.server_version = get_version_tuple(row[0])
 
     def get_default_entity_table_name(provider, entity):
         return DBAPIProvider.get_default_entity_table_name(provider, entity).upper()
@@ -220,7 +235,7 @@ class OraProvider(DBAPIProvider):
     @wrap_dbapi_exceptions
     def execute_returning_id(provider, cursor, sql, arguments):
         set_input_sizes(cursor, arguments)
-        var = cursor.var(cx_Oracle.NUMBER)
+        var = cursor.var(cx_Oracle.STRING, 40, cursor.arraysize, outconverter=int)
         arguments['new_id'] = var
         cursor.execute(sql, arguments)
         return var.getvalue()
