@@ -10,6 +10,13 @@ from os import urandom
 from codecs import BOM_UTF8, BOM_LE, BOM_BE
 from locale import getpreferredencoding
 from bisect import bisect
+from copy import deepcopy, _deepcopy_dispatch
+
+# deepcopy instance method patch for Python < 2.7:
+if types.MethodType not in _deepcopy_dispatch:
+    def _deepcopy_method(x, memo):
+        return type(x)(x.im_func, deepcopy(x.im_self, memo), x.im_class)
+    _deepcopy_dispatch[types.MethodType] = _deepcopy_method
 
 import pony
 from pony import options
@@ -378,6 +385,18 @@ def tostring(x):
     if type(x) == types.InstanceType: return '<%s instance at 0x%X>' % (x.__class__.__name__)
     return '<%s object at 0x%X>' % (x.__class__.__name__)
 
+def strjoin(sep, strings, source_encoding='ascii', dest_encoding=None):
+    "Can join mix of unicode and byte strings in different encodings"
+    strings = list(strings)
+    try: return sep.join(strings)
+    except UnicodeDecodeError: pass
+    for i, s in enumerate(strings):
+        if isinstance(s, str):
+            strings[i] = s.decode(source_encoding, 'replace').replace(u'\ufffd', '?')
+    result = sep.join(strings)
+    if dest_encoding is None: return result
+    return result.encode(dest_encoding, replace)
+
 def make_offsets(s):
     offsets = [ 0 ]
     si = -1
